########################
#Jill Haglund
#12 August 2019
#Matching for IAHRS Paper
#######################

#check if packages are installed, and if not, install them
packages <- c("foreign", "readstata13", "MatchIt")
if (length(setdiff(packages, rownames(installed.packages()))) > 0) {
  install.packages(setdiff(packages, rownames(installed.packages())), repos="http://cran.rstudio.com/")  
}
install.packages("Zelig")
library(Zelig)

#attach packages
lapply(packages, library, character.only = T)

#default the stringsAsFactors argument to FALSE for all functions with that argument
options(stringsAsFactors=FALSE)

#turn off scientific notation
options(scipen=999)

#set seed
set.seed(33603)

#set working directory
setwd("C:/Users/Jill/Dropbox/IACmHR_ITTPaper/ReplicationData/Matching")

#load data
d <- read.dta13("CMPS_MatchingData.dta")


#keep the variables we want for analysis
data <- d[, c("ccode", "year", "art5achr_1", "iacthr_art5_1", "art5achrbin_1", "iacthr_art5bin_1", "v2juhcind", "nhriyearoccupied", "latentembed", "HROsecretariatlocation", "cwar", "gdpcaplog", "numunstated", "numscarring", "numstealth", "popmillions", "RstrctAccess", "speech", "repressionlatent_1", "formalcomplaint")]


#listwise delete
data1 <- na.omit(data)

#attach data
attach(data1)

#########################################################
#Matching - Model 1 Predicting Number of Scarring Torture Events

#Nearest Neighbor (one to one)
nearest.out1<-matchit(art5achrbin_1 ~ v2juhcind + nhriyearoccupied + latentembed + HROsecretariatlocation + cwar + gdpcaplog + popmillions + numunstated + numstealth + RstrctAccess + speech, data = data1, method ="nearest", distance = "logit", discard = "both", reestimate = TRUE)

##Table 1##
nearest.out1
summary(nearest.out1)

#Summary of balance for all data:
#  Means Treated Means Control SD Control Mean Diff eQQ Med eQQ Mean eQQ Max
#distance                      0.3364        0.1788     0.1243    0.1576  0.1426   0.1530  0.4280
#v2juhcind                     0.6593        0.7271     0.9213   -0.0678  0.1746   0.2038  1.0957
#nhriyearoccupied              0.6944        0.5766     0.4959    0.1178  0.0000   0.1111  1.0000
#latentembed                   1.7694        1.8270     0.6921   -0.0575  0.0947   0.1562  0.8745
#HROsecretariatlocation        1.5556        1.1752     1.4240    0.3804  1.0000   0.5833  2.0000
#cwar                          0.3889        0.1533     0.3616    0.2356  0.0000   0.2222  1.0000
#gdpcaplog                     7.7726        7.8745     0.8379   -0.1020  0.2718   0.2920  0.8945
#popmillions                  43.2635       27.4823    43.1266   15.7812  7.7245  15.5400 66.0385
#numunstated                   7.2222        3.4088     6.7623    3.8135  2.5000   3.1944 15.0000
#numstealth                    2.5556        1.8394     3.2792    0.7161  0.0000   0.7778  4.0000
#RstrctAccessNo                0.8333        0.9781     0.1469   -0.1448  0.0000   0.1389  1.0000
#RstrctAccessYes               0.1667        0.0219     0.1469    0.1448  0.0000   0.1389  1.0000
#speech                        1.4444        1.4526     0.5282   -0.0081  0.0000   0.0556  1.0000


#Summary of balance for matched data:
#  Means Treated Means Control SD Control Mean Diff eQQ Med eQQ Mean eQQ Max
#distance                      0.3189        0.2996     0.1669    0.0193  0.0039   0.0211  0.1267
#v2juhcind                     0.6984        0.7805     0.9673   -0.0820  0.0201   0.1218  0.4178
#nhriyearoccupied              0.6857        0.7714     0.4260   -0.0857  0.0000   0.0857  1.0000
#latentembed                   1.7539        1.8348     0.6655   -0.0809  0.1452   0.1397  0.3281
#HROsecretariatlocation        1.5143        1.4286     1.3347    0.0857  0.0000   0.0857  1.0000
#cwar                          0.3714        0.4286     0.5021   -0.0571  0.0000   0.0571  1.0000
#gdpcaplog                     7.7736        7.7510     0.7503    0.0226  0.1131   0.1583  0.9006
#popmillions                  43.7903       38.8967    46.0574    4.8936  2.8395   6.5915 56.3467
#numunstated                   6.8857        7.1429    11.0962   -0.2571  0.0000   1.4571 19.0000
#numstealth                    2.5143        2.8000     4.6450   -0.2857  0.0000   0.6286  9.0000
#RstrctAccessNo                0.8571        0.9143     0.2840   -0.0571  0.0000   0.0571  1.0000
#RstrctAccessYes               0.1429        0.0857     0.2840    0.0571  0.0000   0.0571  1.0000
#speech                        1.4571        1.4571     0.5054    0.0000  0.0000   0.0000  0.0000

#Percent Balance Improvement:
#  Mean Diff.  eQQ Med eQQ Mean   eQQ Max
#distance                  87.7629  97.2683  86.2091   70.3987
#v2juhcind                -21.0580  88.4918  40.2158   61.8706
#nhriyearoccupied          27.2388   0.0000  22.8571    0.0000
#latentembed              -40.5260 -53.2379  10.5629   62.4832
#HROsecretariatlocation    77.4657 100.0000  85.3061   50.0000
#cwar                      75.7463   0.0000  74.2857    0.0000
#gdpcaplog                 77.8147  58.4015  45.7808   -0.6817
#popmillions               68.9909  63.2410  57.5836   14.6761
#numunstated               93.2570 100.0000  54.3851  -26.6667
#numstealth                60.1035   0.0000  19.1837 -125.0000
#RstrctAccessNo            60.5282   0.0000  58.8571    0.0000
#RstrctAccessYes           60.5282   0.0000  58.8571    0.0000
#speech                   100.0000   0.0000 100.0000  100.0000

#Sample sizes:
#  Control Treated
#All           137      36
#Matched        35      35
#Unmatched      86       0
#Discarded      16       1

#create data frame
nearest.data1<-match.data(nearest.out1)

#Regression
reg<-zelig(numscarring ~ art5achr_1 + iacthr_art5_1 + v2juhcind + nhriyearoccupied + latentembed + HROsecretariatlocation + cwar + gdpcaplog + numunstated + numstealth + popmillions + RstrctAccess + speech + repressionlatent_1, data = nearest.data1, model= "negbin")


##Table 2##
summary(reg)

#Coefficients:
#  Estimate Std. Error z value Pr(>|z|)
#art5achr_1              0.038074   0.031487   1.209  0.22660
#iacthr_art5_1          -0.269155   0.119692  -2.249  0.02453

################################################################
#Matching - Model 2 Predicting Number of Stealth Torture Events

#Nearest Neighbor (one to one)
nearest.out2<-matchit(art5achrbin_1 ~ v2juhcind + nhriyearoccupied + latentembed + HROsecretariatlocation + cwar + gdpcaplog + popmillions + numunstated + numscarring + RstrctAccess + speech, data = data1, method ="nearest", distance = "logit", discard = "both", reestimate = TRUE)

##Table 1##
nearest.out2
summary(nearest.out2)

#Summary of balance for all data:
#  Means Treated Means Control SD Control Mean Diff eQQ Med eQQ Mean eQQ Max
#distance                      0.3176        0.1830     0.1176    0.1347  0.1336   0.1315  0.3010
#v2juhcind                     0.6593        0.7271     0.9213   -0.0678  0.1746   0.2038  1.0957
#nhriyearoccupied              0.6944        0.5766     0.4959    0.1178  0.0000   0.1111  1.0000
#latentembed                   1.7694        1.8270     0.6921   -0.0575  0.0947   0.1562  0.8745
#HROsecretariatlocation        1.5556        1.1752     1.4240    0.3804  1.0000   0.5833  2.0000
#cwar                          0.3889        0.1533     0.3616    0.2356  0.0000   0.2222  1.0000
#gdpcaplog                     7.7726        7.8745     0.8379   -0.1020  0.2718   0.2920  0.8945
#popmillions                  43.2635       27.4823    43.1266   15.7812  7.7245  15.5400 66.0385
#numunstated                   7.2222        3.4088     6.7623    3.8135  2.5000   3.1944 15.0000
#numscarring                   8.2500        4.8832     6.4763    3.3668  2.0000   3.1944 11.0000
#RstrctAccessNo                0.8333        0.9781     0.1469   -0.1448  0.0000   0.1389  1.0000
#RstrctAccessYes               0.1667        0.0219     0.1469    0.1448  0.0000   0.1389  1.0000
#speech                        1.4444        1.4526     0.5282   -0.0081  0.0000   0.0556  1.0000


#Summary of balance for matched data:
#  Means Treated Means Control SD Control Mean Diff eQQ Med eQQ Mean eQQ Max
#distance                      0.2859        0.2777     0.1309    0.0081  0.0016   0.0100  0.0956
#v2juhcind                     0.7489        0.7032     1.0267    0.0457  0.0534   0.1154  0.5116
#nhriyearoccupied              0.6765        0.7353     0.4478   -0.0588  0.0000   0.0588  1.0000
#latentembed                   1.7383        1.6148     0.6597    0.1235  0.1374   0.1628  0.4799
#HROsecretariatlocation        1.4706        1.5000     1.3981   -0.0294  0.0000   0.1471  1.0000
#cwar                          0.3529        0.4412     0.5040   -0.0882  0.0000   0.0882  1.0000
#gdpcaplog                     7.7764        7.4670     0.8943    0.3093  0.1376   0.3184  1.1505
#popmillions                  44.3370       47.2069    61.7433   -2.8698  3.2214   8.9339 67.7079
#numunstated                   7.0000        4.7941     7.8346    2.2059  1.5000   2.5000 31.0000
#numscarring                   8.2647        7.3235     8.9501    0.9412  1.0000   1.8235 11.0000
#RstrctAccessNo                0.8824        0.9412     0.2388   -0.0588  0.0000   0.0588  1.0000
#RstrctAccessYes               0.1176        0.0588     0.2388    0.0588  0.0000   0.0588  1.0000
#speech                        1.4706        1.4412     0.5040    0.0294  0.0000   0.0294  1.0000

#Percent Balance Improvement:
#  Mean Diff.  eQQ Med eQQ Mean   eQQ Max
#distance                  93.9700  98.7741  92.4337   68.2498
#v2juhcind                 32.5478  69.4306  43.3818   53.3059
#nhriyearoccupied          50.0658   0.0000  47.0588    0.0000
#latentembed             -114.5601 -45.0235  -4.2357   45.1214
#HROsecretariatlocation    92.2677 100.0000  74.7899   50.0000
#cwar                      62.5494   0.0000  60.2941    0.0000
#gdpcaplog               -203.4135  49.3691  -9.0503  -28.6211
#popmillions               81.8149  58.2970  42.5102   -2.5279
#numunstated               42.1554  40.0000  21.7391 -106.6667
#numscarring               72.0453  50.0000  42.9156    0.0000
#RstrctAccessNo            59.3673   0.0000  57.6471    0.0000
#RstrctAccessYes           59.3673   0.0000  57.6471    0.0000
#speech                  -262.6471   0.0000  47.0588    0.0000

#Sample sizes:
#  Control Treated
#All           137      36
#Matched        34      34
#Unmatched      88       0
#Discarded      15       2

#create data frame
nearest.data2<-match.data(nearest.out2)

#Regression
reg2<-zelig(numstealth ~ art5achr_1 + iacthr_art5_1 + v2juhcind + nhriyearoccupied + latentembed + HROsecretariatlocation + cwar + gdpcaplog + numunstated + numscarring + popmillions + RstrctAccess + speech + repressionlatent_1, data = nearest.data2, model= "negbin")

##Table 2##
summary(reg2)

#Coefficients:
#  Estimate Std. Error z value Pr(>|z|)
#art5achr_1             -0.0034186  0.0510813  -0.067 0.946642
#iacthr_art5_1           0.1263363  0.2128666   0.594 0.552847

########################################################
#Matching - Model 3 Predicting Formal Complaints

#Nearest Neighbor (one to one)
nearest.out3<-matchit(art5achrbin_1 ~ v2juhcind + nhriyearoccupied + latentembed + HROsecretariatlocation + cwar + gdpcaplog + popmillions + numunstated + numscarring + numstealth + RstrctAccess + speech + repressionlatent_1, data = data1, method ="nearest", distance = "logit", discard = "both", reestimate = TRUE)

##Table 1##
nearest.out3
summary(nearest.out3)

#Summary of balance for all data:
#  Means Treated Means Control SD Control Mean Diff eQQ Med eQQ Mean eQQ Max
#distance                      0.3813        0.1632     0.1480    0.2181  0.1614   0.2126  0.3897
#v2juhcind                     0.6593        0.7271     0.9213   -0.0678  0.1746   0.2038  1.0957
#nhriyearoccupied              0.6944        0.5766     0.4959    0.1178  0.0000   0.1111  1.0000
#latentembed                   1.7694        1.8270     0.6921   -0.0575  0.0947   0.1562  0.8745
#HROsecretariatlocation        1.5556        1.1752     1.4240    0.3804  1.0000   0.5833  2.0000
#cwar                          0.3889        0.1533     0.3616    0.2356  0.0000   0.2222  1.0000
#gdpcaplog                     7.7726        7.8745     0.8379   -0.1020  0.2718   0.2920  0.8945
#popmillions                  43.2635       27.4823    43.1266   15.7812  7.7245  15.5400 66.0385
#numunstated                   7.2222        3.4088     6.7623    3.8135  2.5000   3.1944 15.0000
#numscarring                   8.2500        4.8832     6.4763    3.3668  2.0000   3.1944 11.0000
#numstealth                    2.5556        1.8394     3.2792    0.7161  0.0000   0.7778  4.0000
#RstrctAccessNo                0.8333        0.9781     0.1469   -0.1448  0.0000   0.1389  1.0000
#RstrctAccessYes               0.1667        0.0219     0.1469    0.1448  0.0000   0.1389  1.0000
#speech                        1.4444        1.4526     0.5282   -0.0081  0.0000   0.0556  1.0000
#repressionlatent_1           -0.7388        0.0320     0.8474   -0.7708  0.7243   0.7630  1.4742


#Summary of balance for matched data:
#  Means Treated Means Control SD Control Mean Diff eQQ Med eQQ Mean eQQ Max
#distance                      0.3663        0.3078     0.1690    0.0585  0.0284   0.0590  0.1781
#v2juhcind                     0.6984        0.4665     1.0604    0.2319  0.1067   0.2364  1.0957
#nhriyearoccupied              0.6857        0.6571     0.4816    0.0286  0.0000   0.0286  1.0000
#latentembed                   1.7539        1.7704     0.5947   -0.0165  0.0705   0.0705  0.1702
#HROsecretariatlocation        1.5143        1.6857     1.5295   -0.1714  0.0000   0.1714  2.0000
#cwar                          0.3714        0.3143     0.4710    0.0571  0.0000   0.0571  1.0000
#gdpcaplog                     7.7736        7.8334     0.6770   -0.0598  0.1340   0.1322  0.3572
#popmillions                  43.7903       47.4800    51.9234   -3.6897  2.0395   6.6205 59.9465
#numunstated                   6.8857        7.1429    11.4227   -0.2571  0.0000   1.7429 19.0000
#numscarring                   8.3429        8.9143     9.7237   -0.5714  1.0000   1.5429 11.0000
#numstealth                    2.5143        3.1143     5.2958   -0.6000  0.0000   0.9429 10.0000
#RstrctAccessNo                0.8571        0.9429     0.2355   -0.0857  0.0000   0.0857  1.0000
#RstrctAccessYes               0.1429        0.0571     0.2355    0.0857  0.0000   0.0857  1.0000
#speech                        1.4571        1.4857     0.5621   -0.0286  0.0000   0.0857  1.0000
#repressionlatent_1           -0.7257       -0.6927     0.6828   -0.0330  0.0995   0.1220  0.6935

#Percent Balance Improvement:
#  Mean Diff.  eQQ Med eQQ Mean   eQQ Max
#distance                  73.1649  82.4046  72.2520   54.3054
#v2juhcind               -242.1326  38.9159 -16.0304    0.0000
#nhriyearoccupied          75.7463   0.0000  74.2857    0.0000
#latentembed               71.3013  25.6236  54.8469   80.5407
#HROsecretariatlocation    54.9315 100.0000  70.6122    0.0000
#cwar                      75.7463   0.0000  74.2857    0.0000
#gdpcaplog                 41.3745  50.7066  54.7141   60.0696
#popmillions               76.6193  73.5971  57.3968    9.2250
#numunstated               93.2570 100.0000  45.4410  -26.6667
#numscarring               83.0275  50.0000  51.7019    0.0000
#numstealth                16.2174   0.0000 -21.2245 -150.0000
#RstrctAccessNo            40.7923   0.0000  38.2857    0.0000
#RstrctAccessYes           40.7923   0.0000  38.2857    0.0000
#speech                  -252.2857   0.0000 -54.2857    0.0000
#repressionlatent_1        95.7164  86.2570  84.0084   52.9561

#Sample sizes:
#  Control Treated
#All           137      36
#Matched        35      35
#Unmatched      91       0
#Discarded      11       1

#create data frame
nearest.data3<-match.data(nearest.out3)


#Regression
reg3<-zelig(formalcomplaint ~ art5achr_1 + iacthr_art5_1 + v2juhcind + nhriyearoccupied + latentembed + HROsecretariatlocation + cwar + gdpcaplog + numunstated + numscarring + numstealth + popmillions + RstrctAccess + speech + repressionlatent_1, data = nearest.data3, model= "negbin")

##Table 2##
summary(reg3)

#Coefficients:
#  Estimate Std. Error z value  Pr(>|z|)
#art5achr_1              0.075060   0.038898   1.930   0.05365
#iacthr_art5_1           0.003576   0.159537   0.022   0.98212


##############################################
